==> openshift-model-5.8.1-sources.jar: io/fabric8/openshift/api/model/SignatureConditionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SignatureConditionBuilder extends io.fabric8.openshift.api.model.SignatureConditionFluentImpl<io.fabric8.openshift.api.model.SignatureConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SignatureCondition,io.fabric8.openshift.api.model.SignatureConditionBuilder>{
  public SignatureConditionBuilder() {
    this(false);
  }
  public SignatureConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new SignatureCondition(), validationEnabled);
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SignatureCondition(), validationEnabled);
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureConditionFluent<?> fluent,io.fabric8.openshift.api.model.SignatureCondition instance) {
    this(fluent, instance, false);
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureConditionFluent<?> fluent,io.fabric8.openshift.api.model.SignatureCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureCondition instance) {
    this(instance,false);
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SignatureConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SignatureCondition build() {
    SignatureCondition buildable = new SignatureCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SignatureConditionBuilder that = (SignatureConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/SignatureConditionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SignatureConditionBuilder extends io.fabric8.openshift.api.model.SignatureConditionFluentImpl<io.fabric8.openshift.api.model.SignatureConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SignatureCondition,io.fabric8.openshift.api.model.SignatureConditionBuilder>{
  public SignatureConditionBuilder() {
    this(false);
  }
  public SignatureConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new SignatureCondition(), validationEnabled);
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SignatureCondition(), validationEnabled);
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureConditionFluent<?> fluent,io.fabric8.openshift.api.model.SignatureCondition instance) {
    this(fluent, instance, false);
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureConditionFluent<?> fluent,io.fabric8.openshift.api.model.SignatureCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureCondition instance) {
    this(instance,false);
  }
  public SignatureConditionBuilder(io.fabric8.openshift.api.model.SignatureCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SignatureConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SignatureCondition build() {
    SignatureCondition buildable = new SignatureCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SignatureConditionBuilder that = (SignatureConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
